OpenAiModel

Enum OpenAiModel 

pub enum OpenAiModel {
Show 24 variants Gpt5, Gpt5Nano, Gpt5Mini, Gpt5Pro, Gpt5_1, Gpt5_1Codex, Gpt5_1CodexMini, Gpt5_1CodexMax, Gpt5_2, Gpt5_2Pro, Gpt5_2Codex, Gpt5_3, Gpt5_3Codex, Gpt5_4, Gpt5_4Pro, Gpt5Codex, Gpt4_1, Gpt4_1Mini, Gpt4_1Nano, Gpt4o, Gpt4oMini, O3, O3Mini, O4Mini,
}
Exhaustive list of models officially supported by the OpenAI back-end.

Keeping the list small avoids accidental typos while still allowing arbitrary model names through Model::Custom.

Variants



Gpt5



Gpt5Nano



Gpt5Mini



Gpt5Pro



Gpt5_1



Gpt5_1Codex



Gpt5_1CodexMini



Gpt5_1CodexMax



Gpt5_2



Gpt5_2Pro



Gpt5_2Codex



Gpt5_3



Gpt5_3Codex



Gpt5_4



Gpt5_4Pro



Gpt5Codex



Gpt4_1



Gpt4_1Mini



Gpt4_1Nano



Gpt4o



Gpt4oMini



O3



O3Mini



O4Mini