Module provider

Module provider 

Re-exports

pub use crate::generic::StreamingEventsProvider;

Structs

ChatCompleteParameters
TranscriptionRequest
Provider-agnostic audio transcription request.
TranscriptionResult
TranscriptionSegment

Traits

ChatCompletionProvider
A backend turns a chat prompt into a network call to a concrete provider (OpenAI, Ollama, Anthropic, …) and parses the structured chat response.
PromptExecutionProvider
A backend turns a prompt into a network call to a concrete provider (OpenAI, Ollama, Anthropic, …) and parses the structured response.
StreamingChatProvider
A provider that can deliver the model’s answer incrementally.
TranscriptionProvider
Provider capability for converting audio to text.

Type Aliases

BoxedResponseFut