Struct ChatCompleteParameters
Source pub struct ChatCompleteParameters<M> {
pub messages: Vec<M>,
pub model: Model,
pub tools: Option<Vec<GenericFunctionSpec>>,
pub temperature: Option<f64>,
pub response_format: Option<Value>,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.