pub enum OpenAiModel {
Gpt5,
Gpt5Nano,
Gpt5Mini,
Gpt5_1,
Gpt5_2,
Gpt4o,
Gpt4oMini,
O3,
O3Mini,
O4Mini,
}Expand description
Exhaustive list of models officially supported by the OpenAI back-end.
Keeping the list small avoids accidental typos while still allowing
arbitrary model names through Model::Custom.
Variants