Re-exports
pub use crate::generic::StreamingEventsProvider;
Structs
Traits
- Chat
Completion Provider - A backend turns a chat prompt into a network call to a concrete provider (OpenAI, Ollama, Anthropic, …) and parses the structured chat response.
- Prompt
Execution Provider - A backend turns a prompt into a network call to a concrete provider (OpenAI, Ollama, Anthropic, …) and parses the structured response.
- Streaming
Chat Provider - A provider that can deliver the model’s answer incrementally.